@@ -1,4 +1,5 @@
 from .constants import Constant
+from .exceptions import TilingDecodeException
 from .parsing import Arguments
 from .paths import PathUtil
 from .web import open_browser_tab
@@ -11,4 +12,5 @@ __all__ = [
     "Constant",
     "kill_server",
     "PathUtil",
+    "TilingDecodeException",
 ]
